@@ -607,9 +607,15 @@ class DocumentStateCode:
 
 class DocumentType:
     '''Enumeração dos possíveis tipos de um :class:`Document <Document>`.'''
+    #: Histórico escolar parcial. Equivalente a ``partial_academic_transcript``.
+    PARTIAL_ACADEMIC_TRANSCRIPT = 1
+
     #: Diploma digital. Equivalente a ``digital_degree``.
     DIGITAL_DEGREE = 2
 
+    #: Histórico escolar final. Equivalente a ``final_academic_transcript``.
+    FINAL_ACADEMIC_TRANSCRIPT = 3
+
     #: Documentação acadêmica. Equivalente a ``academic_doc_mec_degree``.
     ACADEMIC_DOC_MEC_DEGREE = 4
 
